# -*- coding: utf-8 -*-

# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Actions for the Notes page of the Ubuntu One website."""

from sst.actions import *
from loading import *
from selenium.webdriver.common import keys


def open():
    """Open the notes page and check its title with an assert."""
    click_link(_get_notes_link(), wait=False)
    switch_to_window()
    assert_page_title()


def _get_notes_link():
    return get_element_by_css('#main-nav .notes')


def assert_page_title():
    """Assert that the title of the page is the expected."""
    assert_title(u'Ubuntu One : Notes')


def assert_note_exists(title):
    get_element(tag='li', text=title)


def select_note(title):
    click_link(_get_note_link(title))
    wait_for_action_to_complete()
    

def _get_note_link(title):
    return get_element(tag='a', css_class='note_link', text=title)


def assert_note(title, body):
    if title:
        displayed_title = _get_note_title()
        assert displayed_title == title, \
               'Title is %(displayed)s, but it should be %(expected)s.' % \
               {'displayed':displayed_title, 'expected':title}
    if body:
        displayed_body = _get_note_body()
        assert displayed_body == body, \
               'Body is %(displayed)s, but it should be %(expected)s.' % \
               {'displayed':displayed_body, 'expected':body}


def _get_note_title():
    return get_element_by_css('#notes-main > h2').text


def _get_note_body():
    return get_element_by_css('#notes-main > .note-view').text


def add_note(title, body):
    """Click the button to add note."""
    _click_add_note()
    _fill(title, body)
    _save()


def _click_add_note():
    link_add = get_element(css_class='add-button')
    click_link(link_add)
    wait_for_action_to_complete()


def _fill(title, body):
    if title:
        write_textfield('id_title', title)
    if body:
        switch_to_frame('id_body_editor')
        body_element = get_element(tag='body')
        body_element.send_keys(keys.Keys().CONTROL, 'a')
        body_element.send_keys(keys.Keys().DELETE)
        body_element.send_keys(body)
        switch_to_frame()


def _save():
    link_save = get_elements(css_class='save-button')[0]
    click_element(link_save)
    wait_for_action_to_complete()


def edit_note(edited_title, edited_body):
    """Click the button to edit note."""
    _click_edit_note()
    _fill(edited_title, edited_body)
    _save()


def _click_edit_note():
    link_edit = get_elements(css_class='edit-button')[0]
    click_link(link_edit)
    wait_for_action_to_complete()


def delete_note(title):
    """Delete the note"""
    select_note(title)
    delete_button = get_element_by_css('li.selected > a.delete-button')
    click_element(delete_button, wait=False)
    accept_alert()
    wait_for_action_to_complete()


def assert_note_was_deleted(title):
    fails(assert_note_exists, title)
    assert_text('notes-main', '"%s" has been deleted' % title)
