# -*- coding: utf-8 -*-

# Authors: 
#     Rick McBride <rick.mcbride@canonical.com>
#     Leo Arias <leo.arias@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Actions for the Services page of the Ubuntu One website."""

from sst.actions import *

def open():
    """Open the services page and assert it's title."""
    go_to('/services/')
    assert_page_title()

def assert_page_title():
    """Assert that the title of the page is the expected."""
    assert_title(u'Ubuntu One : Services')

def agree_and_subscribe_to_free_plan():
    click_button(get_element(name='subscribe'))

def assert_services_information():
    """Assert that the information about the services is the expected."""
    assert_free_service_information()
    assert_music_streaming_service_information()
    assert_storage_service_information()
    assert_discount_information()

def assert_free_service_information():
    """Assert that the information about the free service is the expected."""
    get_element(tag='h2', text='Free')
    get_element(tag='li', text='File sync across platforms')
    get_element(tag='li', text='Share folders and files')
    get_element(tag='li', text='Access on your mobile')

def assert_music_streaming_service_information():
    """Assert that the information about the music streaming service is 
    the expected.

    """
    get_element(tag='h2', text='Music Streaming')
    get_element(css_class='try-free', text='Try for FREE')
    get_element(tag='li', text='Music streaming on your mobile')
    get_element(tag='li', text='20 GB of Storage for all your data')
    get_element(tag='li', text='Listen offline')
    get_element(tag='li', text='$3.99 / month or $39.99 / year')

def assert_storage_service_information():
    """Assert that the information about the storage service is the 
    expected.

    """
    get_element(tag='h2', text='Storage')
    get_element(tag='li', text='20 GB')
    get_element(tag='li', text='$2.99 / month')
    get_element(tag='li', text='or $29.99 / year')

def assert_discount_information():
    """Assert that the yearly discount information is the expected."""
    get_element(tag='h3', text='Discount')
    get_element(tag='p', text='Two months free on Music Streaming and Storage '
                              'when you sign up for 12 months')

def buy_music_streaming_monthly():
    """Buy the monthly music streaming service."""
    set_radio_value('ms1')
    click_button(get_elements(css_class='buy-now',
                              text='Buy now and go to checkout')[0])

def buy_music_streaming_yearly():
    """Buy the yearly music streaming service."""
    set_radio_value('ms2')
    buy_music_streaming()

def buy_music_streaming():
    """Click the button to buy the music streaming service."""
    click_button(get_elements(css_class='buy-now',
                              text='Buy now and go to checkout')[0])

def assert_storage(quantity):
    """Asert the storage quantity selected and its space and price. 
    
    Keyword arguments:
    quantity -- The expected storage quantity.

    """
    assert_text('qty', str(quantity))
    assert_text('storage-gb', '%sGB' % (quantity * 20))
    monthly_price = quantity * 2.99
    assert_text('storage-monthly-price', '$%s' % monthly_price)
    annual_price = quantity * 29.99
    assert_text('storage-annual-price', '$%s' % annual_price)

def increase_storage_quantity():
    """Click the button that increases the storage quantity to buy."""
    click_button('plus_qty')

def decrease_storage_quantity():
    """Click the button that decreases the storage quantity to buy."""
    click_button('minus_qty')

def set_storage_quantity(quantity):
    """Set the storage quantity to buy.
    
    Keyword arguments: 
    quantity -- The quantity to buy.   

    """
    write_textfield('qty', str(quantity))
    
def buy_extra_storage_monthly():
    """Buy the monthly extra storage service."""
    set_radio_value('st1')
    buy_extra_storage()

def buy_extra_storage_yearly():
    """Buy the yearly extra storage service."""
    set_radio_value('st2')
    buy_extra_storage()

def buy_extra_storage():
    """Click the button to buy extra storage."""
    click_button(get_elements(css_class='buy-now',
                              text='Buy now and go to checkout')[1])
