# -*- coding: utf-8 -*-

# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Set up actions for Ubuntu One sst tests."""

from sst.actions import *
from config import *
from data.user import User
import actions.header as header_actions
import actions.sso as sso_actions
import actions.services as services_actions
import actions.dashboard as dashboard_actions
import uuid
from utils import mail
try:
    from _passwords import full_name, email, password
except:
    skip('Try adding a _passwords.py file to the shared folder if you ' \
        'expect this to work. Read the README.txt file ;)')


def setup(new_user=False, user=None):
    """Log in to the Ubuntu One website. Optionally, you can create a new user.

    After calling setup, the browser will be in the Dashboard ready to
    start testing.

    Keyword arguments:
    new_user -- Indicates if a new user has to be created for the test.

    """
    set_base_url(get_base_url())
    set_wait_timeout(DEFAULT_TIMEOUT)
    go_to()
    wait_for(assert_title, 'Ubuntu One : Home')
    header_actions.click_login_or_sign_up()
    test_user = user
    if new_user:
        if user is None:
            user_uuid = str(uuid.uuid1())
            user_name = 'Test user ' + user_uuid
            user_email = user_uuid + '@' + IMAP_SERVER
            user_password = 'Hola123*'
            test_user = User(user_name, user_email, user_password)
        sso_actions.create_new_account(test_user)
        confirmation_code  = \
            mail.get_confirmation_code_for_address(test_user.email)
        sso_actions.confirm_email(confirmation_code)
    else:
        if user is None:
            test_user = User(full_name, email, password)
        sso_actions.login(test_user)
    if new_user:
        services_actions.agree_and_subscribe_to_free_plan()
    dashboard_actions.wait_for_page_to_load()
    header_actions.assert_login(test_user.full_name)

def get_base_url():
    base_url = None
    if ENVIRONMENT == 'staging':
        base_url = 'https://staging.one.ubuntu.com'
    elif ENVIRONMENT == 'edge':
        base_url = 'https://edge.one.ubuntu.com'
    elif ENVIRONMENT == 'production':
        base_url = 'https://one.ubuntu.com'
    else:
        skip('Unknown environment: %s.' % ENVIRONMENT)
    return base_url
